@@ -10,7 +10,7 @@ from decimal import Decimal
 
 import proteus.config
 
-__version__ = "5.0.7"
+__version__ = "5.0.12"
 __all__ = ['Model', 'Wizard', 'Report']
 
 _MODELS = threading.local()
@@ -1235,10 +1235,15 @@ class Report(object):
         self._proxy = self._config.get_proxy(name, type='report')
 
     def execute(self, models=None, data=None):
-        ids = [m.id for m in models] if models else data.get('ids', [])
+        if models:
+            ids = [m.id for m in models]
+        elif data:
+            ids = data.get('ids', [])
+        else:
+            ids = []
         if data is None:
             data = {
-                'id': ids[0],
+                'id': ids[0] if ids else None,
                 'ids': ids,
                 }
             if models:
@@ -1289,6 +1294,8 @@ def _convert_action(action, data=None, context=None, config=None):
         with config.reset_context(), config.set_context(action_ctx):
             if res_id is None:
                 return Model_.find(domain)
+            elif isinstance(res_id, int):
+                return [Model_(res_id)]
             else:
                 return [Model_(id_) for id_ in res_id]
     elif action['type'] == 'ir.action.wizard':
